==> querydsl-parser-0.1-sources.jar: foundation/jpa/querydsl/StateRPar4.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateRPar4 extends StackState<foundation.rpg.common.symbols.RPar, StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>>> {

// NoStack:
// Stack:
    public StateRPar4(foundation.jpa.querydsl.QueryFactory factory, foundation.rpg.common.symbols.RPar node, StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitEqual(foundation.rpg.common.symbols.Equal symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitEqual(symbol);
    }

    @Override
    public State visitIn(foundation.rpg.common.symbols.In symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitIn(symbol);
    }

    @Override
    public State visitTilda(foundation.rpg.common.symbols.Tilda symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitTilda(symbol);
    }

    @Override
    public State visitEnd(foundation.rpg.parser.End symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitEnd(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitAnd(symbol);
    }

    @Override
    public State visitDot(foundation.rpg.common.symbols.Dot symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitDot(symbol);
    }


// Shift:
// Accept:
    @Override
    public List<Object> stack() {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return Arrays.asList(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode());
    }

}

==> querydsl-parser-0.2-sources.jar: foundation/jpa/querydsl/StateRPar4.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateRPar4 extends StackState<foundation.rpg.common.symbols.RPar, StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>>> {

// NoStack:
// Stack:
    public StateRPar4(foundation.jpa.querydsl.QueryFactory factory, foundation.rpg.common.symbols.RPar node, StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitEqual(foundation.rpg.common.symbols.Equal symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitEqual(symbol);
    }

    @Override
    public State visitIs(foundation.rpg.common.symbols.Is symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitIs(symbol);
    }

    @Override
    public State visitNot(foundation.rpg.common.symbols.Not symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitNot(symbol);
    }

    @Override
    public State visitIn(foundation.rpg.common.symbols.In symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitIn(symbol);
    }

    @Override
    public State visitTilda(foundation.rpg.common.symbols.Tilda symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitTilda(symbol);
    }

    @Override
    public State visitEnd(foundation.rpg.parser.End symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitEnd(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitAnd(symbol);
    }

    @Override
    public State visitDot(foundation.rpg.common.symbols.Dot symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return stack4.visitObject(getFactory().is(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitDot(symbol);
    }


// Shift:
// Accept:
    @Override
    public List<Object> stack() {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.Identifier, ? extends State>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.Identifier, ? extends State> stack3 = stack2.getPrev();
		State stack4 = stack3.getPrev();
        return Arrays.asList(stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode());
    }

}
